# Proposer - Create Transaction Payload

The proposer is a fiduciary whose responsibility is to make sound financial decisions on behalf of a business and determine where funds are moving from, where to and in which amount. The reasons for sending funds may range across settlement, exchanging, staking and more.

The proposer MUST include the workflow type and all arguments required by a workflow, such as `from_address`, `to_address`, `asset_name`, etc., as well as a UTC datetime representing the time when the transaction is proposed.

The proposer must combine these values into a JSON file, such as:

```json
{
	"workflow": ["cosmos", "withdraw"],
	"values": {
		"delegate_address": "kyve1q9w3nar74up6mxnwd428wpr5nffcw3360tkxer",
		"validator_address": "kyvevaloper1ghpmzfuggm7vcruyhfzrczl4aczy8gas8guslh",
		"asset_name": "KYVE",
		"asset_amount": "0.4",
		"chain_name": "korellia"
	},
	"proposal_datetime": "2025-01-28T18:18:00"
}
```

## Requirements

* [Quorum PGP Key](../operator/quorum-entropy-ceremony.md)

* [Air-Gapped Bundle](../provisioner/air-gapped-bundle.md)

	* The proposer  should print photographic evidence from digital cameras which is stored in a PGP signed repository. The photographs should be of the top and underside of the vacuum sealed object.

	* The proposer should verify the commit signatures of the photographs they are printing against a list of permitted PGP keys found in the `vaults` repo

* Online Machine

* Clone the [Vaults Repository](../../../all-levels/create-vaults-repository.md) for your organization to the machine

## Procedure

1. Turn on online machine 

1. Clone the repository if it's not available locally:

	* `git clone <repository_git_url>`

1. Pull the latest changes from the `ceremonies` repository

	* `git pull origin main`

1. Unseal the SD Card Pack

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Plug a fresh SD card into the online machine

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Save the `vaults` repo to the SD card, referred to as the Ceremony SD card

	* `cp -r ~/vaults/ /media/<device_name>/`

1. Unplug the Ceremony SD card

1. Unseal the tamper proofed bundle

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-unsealing}}

1. Insert the AirgapOS SD card into the airgapped machine and turn it on

1. Once booted, unplug the AirgapOS SD card 

1. Plug in the Ceremony SD card

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Plug in the Operator smart card

1. Set a local variable `smart_card_id` to the smart card OpenPGP key id:
	
	* `smart_card_id="$(oct list -i | head -1)"`

1. Copy the git repo locally from the Ceremony SD card

	* `cp -r /media/<device_name>/vaults /root/vaults`
	
1. Change into the vaults directory:

	* `cd /root/vaults`

1. Create a new payloads directory in the `vaults` repository for the date on which the ceremony for the transaction will take place if it doesn't already exist

	* `mkdir -p <namespace>/ceremonies/<date>/payloads`

	* e.g `mkdir -p solana-01/ceremonies/2025-01-01/payloads`

1. Create a new file `payload_<num>.json`, for example `payload_1.json`

	* `touch <namespace>/ceremonies/<date>/payloads/payload_<num>.json`

	* e.g `touch solana-01/ceremonies/2025-01-01/payloads/payload_1.json`

1. Collect data for the transaction being sent, and structure it according to the template below, replacing values with valid ones. The values have to come from a organization approved list of values, for each field, except for `datetime` which is just the current date and time.

	* Write the data to the file: `vim <namespace>/ceremonies/<date>/payloads/payload_<num>.json`

	```json
	{
		"workflow": ["<workflow_namespace>", "<workflow_name>"],
		"values": {
			"<workflow_field>": "<workflow_value>"
		},
		"proposal_datetime": "<datetime>"
	}
	```

	Example data object:

	```json
	{
		"workflow": ["cosmos", "withdraw"],
		"values": {
			"delegate_address": "kyve1q9w3nar74up6mxnwd428wpr5nffcw3360tkxer",
			"validator_address": "kyvevaloper1ghpmzfuggm7vcruyhfzrczl4aczy8gas8guslh",
			"asset_name": "KYVE",
			"asset_amount": "0.4",
			"chain_name": "korellia"
		},
		"proposal_datetime": "2025-01-28T18:18:00"
	}
	```
1. Import the keys relevant to the ceremony:

	* `gpg --import <namespace>/keyring.asc`

1. Sign the data in the CLI using `gpg` or another OpenPGP implementation:

	* `gpg --detach-sign <namespace>/ceremonies/<date>/payloads/<payload>_<num>.json > <namespace>/ceremonies/<date>/payloads/payload_<num>_$smart_card_id.sig`

	* e.g `gpg --detach-sign solana-01/ceremonies/2025-01-01/payloads/payload_1.json > solana-01/ceremonies/2025-01-01/payloads/payload_1_F4BF5C81EC78A5DD341C91EEDC4B7D1F52E0BA4D.sig`

1. Stage the new file:

	* `git add <namespace>/ceremonies/<date>/payloads/<payload>.<num>.$smart_card_id.sig`

1. Create a signed git commit:

	* `git commit -S -m "add payload signature for payload_<num>.sig using $smart_card_id"`

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Copy the updated ceremonies repo to the SD card

	* `cp -r /root/vaults /media/<device_name>/vaults`

1. Unplug the SD card from the air-gapped machine

1. Plug in the SD card into the online machine

1. {{ #include ../../../../component-documents/finding-device-name.md:content }}

1. Copy the updated repository locally:

	* `cp -r /media/<device_name>/vaults ~/`

1. Change into locally copied directory

	* `cd ~/vaults`

1. Push the latest commit to the repository
	
	* `git push origin main`

1. Notify relevant individuals that there are new transactions queued up, and that a ceremony should be scheduled. This can be automated in the future so that when a commit is made or PR opened, others are notified, for example using a incident management tool.

1. Tamper proof the AirgapOS and Air-gapped laptop

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing}}
